#!/bin/sh -fu

. install2-init-functions

fstab="$destdir/etc/fstab"

# From kernel sources (fs/quota/Kconfig):
#Currently, it works for the
#ext2, ext3, ext4, jfs, ocfs2 and reiserfs file systems.
#Note that gfs2 and xfs use their own quota system.
supported_fs_list='ext[234]|jfs|ocfs2|reiserfs|gfs2|xfs'

vz=1
[ -n "$(sed -n 's|^UUID=[^[:space:]]\+[[:space:]]\+/var/lib/vz[[:space:]].*|&|p' <"$fstab")" ] ||
[ -n "$(sed -n 's|^UUID=[^[:space:]]\+[[:space:]]\+/var/lib/vz/private[[:space:]].*|&|p' <"$fstab")" ] ||
vz=

lib=1
[ -n "$(sed -n 's|^UUID=[^[:space:]]\+[[:space:]]\+/var/lib[[:space:]].*|&|p' <"$fstab")" ] ||
	lib=

sed -n -r 's;^UUID=[^[:space:]]+[[:space:]]+(/[^[:space:]]+)[[:space:]]+('$supported_fs_list')[[:space:]]+([^[:space:]]+).*;\1\t\3;p' <"$fstab" |
while read dir opts; do
	# ovz quota is not compatible with fs quota
	case $dir in
		/var)
			[ -z "$lib$vz" ] || continue
			;;
		/var/lib)
			[ -z "$vz" ] || continue
			;;
		/var/lib/vz|/var/lib/vz/private)
			continue
			;;
	esac

	for t in usrquota grpquota; do
		if [ -n "${opts##*$t*}" ]; then
			opts="$opts,$t"
			sed -i -r 's;^(UUID=[^[:space:]]+[[:space:]]+'"$dir"'+[[:space:]]+('$supported_fs_list')[[:space:]]+)([^[:space:]]+)(.*);\1\3,'$t'\4;' "$fstab"
		fi
	done
	mount "$destdir$dir" -oremount,"$opts"
	chroot $destdir sh -c "/sbin/quotacheck -m -u $dir"
	chroot $destdir sh -c "/sbin/quotacheck -m -g $dir"
	chroot $destdir sh -c "/sbin/quotaon $dir"
done

exit 0
